@@ -11,7 +11,7 @@ def deploy_app_awx():
     data = {"commit_ref_name": __main__.os.environ.get('CI_COMMIT_REF_NAME'),
         "job_id": __main__.os.environ.get('CI_JOB_ID'),
         "job_name": __main__.os.environ.get('CI_JOB_NAME'),
-        "manifest": __main__.manifest_dat,
+        "manifest": manifest_dat,
         "project_name": __main__.os.environ.get('CI_PROJECT_NAME'),
         "short_sha": __main__.os.environ.get('CI_COMMIT_SHORT_SHA'),
         "user_email": __main__.os.environ.get('GITLAB_USER_EMAIL'),
